@@ -201,8 +201,7 @@ fn get_terminal_info() -> TerminalInfo {
 
 fn get_config_path(shell: &str) -> Option<PathBuf> {
     if shell == "nu" {
-        return dirs_next::config_dir()
-            .map(|config_dir| config_dir.join("nushell").join("config.nu"));
+        return dirs::config_dir().map(|config_dir| config_dir.join("nushell").join("config.nu"));
     }
 
     utils::home_dir().and_then(|home_dir| {
